@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new {
     return bless {}, shift;
@@ -62,8 +62,8 @@ sub _end {}; # vim placeholder
 1;
 =head1 NAME
 
-Mock::Sub - Mock package, module, object and standard subs, with ability to
-collect stats.
+Mock::Sub - Mock package, module, object and standard subroutines, with ability
+to collect stats on them.
 
 
 =head1 SYNOPSIS
@@ -86,6 +86,14 @@ collect stats.
     $foo->called;       # was the sub called?
     $foo->call_count;   # how many times was it called?
 
+    # create a mock object to reduce typing when multiple subs
+    # are mocked
+
+    my $mock = Mock::Sub->new;
+
+    my $foo = $mock->('Package::foo');
+    my $bar = $mock->('Package::bar');
+
     # have the mocked sub return something when it's called
 
     $foo = $mock->('Package::foo', return_value => 'True');
@@ -98,14 +106,6 @@ collect stats.
 
     $foo->reset;
 
-    # create a mock object to reduce typing when multiple subs
-    # are mocked
-
-    my $mock = Mock::Sub->new;
-    
-    my $foo = $mock->('Package::foo');
-    my $bar = $mock->('Package::bar');
-    my $baz = $mock->('Package::baz');
 
 =head1 DESCRIPTION
 
